Package: ctsGE
Title: Clustering of Time Series Gene Expression data
Version: 1.36.0
Authors@R: c(person("Michal", "Sharabi-Schwager",
                email = "michalsharabi@gmail.com", role = c("aut", "cre")),
                person("Ron", "Ophir",
                    email = "ron@volcani.agri.gov.il", role = "aut"))
Description: Methodology for supervised clustering of potentially many predictor
                variables, such as genes etc., in time series datasets
                Provides functions that help the user assigning genes to
                predefined
                set of model profiles.
Depends: R (>= 3.2)
Imports: ccaPP, ggplot2, limma, reshape2, shiny, stats, stringr, utils
Suggests: BiocStyle, dplyr, DT, GEOquery, knitr, pander, rmarkdown,
        testthat
URL: https://github.com/michalsharabi/ctsGE
BugReports: https://github.com/michalsharabi/ctsGE/issues
License: GPL-2
RoxygenNote: 5.0.1
VignetteBuilder: knitr
biocViews: ImmunoOncology, GeneExpression, Transcription,
        DifferentialExpression, GeneSetEnrichment, Genetics, Bayesian,
        Clustering, TimeCourse, Sequencing, RNASeq
git_url: https://git.bioconductor.org/packages/ctsGE
git_branch: RELEASE_3_22
git_last_commit: f0f5237
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:23:58 UTC; biocbuild
Author: Michal Sharabi-Schwager [aut, cre],
  Ron Ophir [aut]
Maintainer: Michal Sharabi-Schwager <michalsharabi@gmail.com>
