# Generated by roxygen2: do not edit by hand

export(ClustIndexes)
export(PlotIndexesClust)
export(PreparingTheIndexes)
export(ctsGEShinyApp)
export(index)
export(readTSGE)
import(ccaPP)
import(ggplot2)
import(limma)
import(reshape2)
import(shiny)
import(stats)
import(stringr)
import(utils)
