# ctsGE
Clustering of time series gene expression data
## Installing ctsGE


```{r,eval=FALSE,warning=FALSE,message=FALSE}
BiocManager::install("ctsGE")
```
**OR**

```{r,eval=FALSE,warning=FALSE,message=FALSE}
devtools::install_github("michalsharabi/ctsGE")
```

**OR:**

*Download [source](https://github.com/michalsharabi/ctsGE/tree/master/source)*
```{r, eval=FALSE,warning=FALSE,message=FALSE }
install.packages("ctsGE.tar.gz",repos=NULL,type="source")
```
## ctsGE usage
Tutotial and examples can be found  [here](https://htmlpreview.github.io/?https://github.com/michalsharabi/ctsGE/blob/master/inst/doc/ctsGE.html)

